@@ -1,5 +1,5 @@
 from crowdin_api.client import CrowdinClient
 
 __all__ = ["CrowdinClient"]
-__author__ = "Сrowdin"
-__version__ = "1.0.4"
+__author__ = "Crowdin"
+__version__ = "1.1.1"
